Sophie

Sophie

distrib > Fedora > 13 > i386 > by-pkgid > b6bbc00930195bf73fbd2d67eb654d36 > files > 4

hct-0.7.60-2.fc13.src.rpm

diff -up hct-0.7.60/lang/hdl/cdl/parser.pm.hct hct-0.7.60/lang/hdl/cdl/parser.pm
--- hct-0.7.60/lang/hdl/cdl/parser.pm.hct	2010-05-15 19:24:20.145311903 +0530
+++ hct-0.7.60/lang/hdl/cdl/parser.pm	2010-05-15 19:25:39.455166180 +0530
@@ -12,7 +12,7 @@
 #
 ####################################################################
 
-package lang::hdl::cdl::parser;
+package HCT::lang::hdl::cdl::parser;
 use vars qw (@ISA);
 use strict;
 
diff -up hct-0.7.60/lang/hdl/cdl.pm.hct hct-0.7.60/lang/hdl/cdl.pm
--- hct-0.7.60/lang/hdl/cdl.pm.hct	2010-05-15 19:20:54.633185569 +0530
+++ hct-0.7.60/lang/hdl/cdl.pm	2010-05-15 19:22:37.581167659 +0530
@@ -1,4 +1,4 @@
-# cdl.pm (lang::hdl::cdl)
+# cdl.pm (HCT::lang::hdl::cdl)
 #
 # Copyright 2008, 2009
 # Slade Maurer
@@ -20,7 +20,7 @@
 
 =head1 NAME
 
-lang::hdl::cdl - Class of Cyclicity CDL language. 
+HCT::lang::hdl::cdl - Class of Cyclicity CDL language. 
 
 =head1 DESCRIPTION
 
@@ -31,7 +31,7 @@ http://cyclicity-cdl.sourceforge.net/
 
 =cut
 
-package lang::hdl::cdl;
+package HCT::lang::hdl::cdl;
 
 # Use base object for creating a new language.
 use base 'HCT::Lang::LangDriver';
@@ -39,8 +39,8 @@ use base 'HCT::Lang::LangDriver';
 use strict;
 use warnings;
 
-require lang::hdl::cdl::lexer;
-require lang::hdl::cdl::parser;
+require HCT::lang::hdl::cdl::lexer;
+require HCT::lang::hdl::cdl::parser;
 
 our @FILE_ASSOCIATIONS = ('cdl');
 
@@ -62,8 +62,8 @@ sub new
 	my $class = shift;
 	my $self = $class->SUPER::new (@_);
 
-	$self->parser (new lang::hdl::cdl::parser);
-	$self->lexer  (new lang::hdl::cdl::lexer);
+	$self->parser (new HCT::lang::hdl::cdl::parser);
+	$self->lexer  (new HCT::lang::hdl::cdl::lexer);
 
 	$self->output->metrics (\%OUTPUT_METRICS);
 	$self->output->levels (\%OUTPUT_LEVELS);
diff -up hct-0.7.60/lang/hdl/verilog/lexer.pm.hct hct-0.7.60/lang/hdl/verilog/lexer.pm
--- hct-0.7.60/lang/hdl/verilog/lexer.pm.hct	2010-05-15 19:26:04.493162648 +0530
+++ hct-0.7.60/lang/hdl/verilog/lexer.pm	2010-05-15 19:26:34.428168751 +0530
@@ -18,7 +18,7 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with HCT.  If not, see <http://www.gnu.org/licenses/>.
 
-package lang::hdl::verilog::lexer;
+package HCT::lang::hdl::verilog::lexer;
 
 use base 'HCT::Lang::LexerDriver';
 
diff -up hct-0.7.60/lang/hdl/verilog/parser.pm.hct hct-0.7.60/lang/hdl/verilog/parser.pm
--- hct-0.7.60/lang/hdl/verilog/parser.pm.hct	2010-05-15 19:26:08.089287302 +0530
+++ hct-0.7.60/lang/hdl/verilog/parser.pm	2010-05-15 19:26:50.238290953 +0530
@@ -12,7 +12,7 @@
 #
 ####################################################################
 
-package lang::hdl::verilog::parser;
+package HCT::lang::hdl::verilog::parser;
 use vars qw (@ISA);
 use strict;
 
diff -up hct-0.7.60/lang/hdl/verilog.pm.hct hct-0.7.60/lang/hdl/verilog.pm
--- hct-0.7.60/lang/hdl/verilog.pm.hct	2010-05-15 19:20:59.385161846 +0530
+++ hct-0.7.60/lang/hdl/verilog.pm	2010-05-15 19:23:22.966188749 +0530
@@ -1,4 +1,4 @@
-# verilog.pm (lang::hdl::verilog)
+# verilog.pm (HCT::lang::hdl::verilog)
 #
 # Copyright 2008, 2009
 # Slade Maurer
@@ -20,7 +20,7 @@
 
 =head1 NAME
 
-lang::hdl::verilog - Class of Verilog language. 
+HCT::lang::hdl::verilog - Class of Verilog language. 
 
 =head1 DESCRIPTION
 
@@ -39,7 +39,7 @@ L<http://www.externsoft.ch/download/veri
 
 =cut
 
-package lang::hdl::verilog;
+package HCT::lang::hdl::verilog;
 
 # Use base object for creating a new language.
 use base 'HCT::Lang::LangDriver';
@@ -47,8 +47,8 @@ use base 'HCT::Lang::LangDriver';
 use strict;
 use warnings;
 
-require lang::hdl::verilog::lexer;
-require lang::hdl::verilog::parser;
+require HCT::lang::hdl::verilog::lexer;
+require HCT::lang::hdl::verilog::parser;
 
 our @FILE_ASSOCIATIONS = ('v');
 
@@ -70,8 +70,8 @@ sub new
 	my $class = shift;
 	my $self = $class->SUPER::new (@_);
 
-	$self->parser (new lang::hdl::verilog::parser);
-	$self->lexer (new lang::hdl::verilog::lexer);
+	$self->parser (new HCT::lang::hdl::verilog::parser);
+	$self->lexer (new HCT::lang::hdl::verilog::lexer);
 
 	$self->output->metrics (\%OUTPUT_METRICS);
 	$self->output->levels (\%OUTPUT_LEVELS);
diff -up hct-0.7.60/lang/hdl/vhdl/lexer.pm.hct hct-0.7.60/lang/hdl/vhdl/lexer.pm
--- hct-0.7.60/lang/hdl/vhdl/lexer.pm.hct	2010-05-15 19:26:59.416313677 +0530
+++ hct-0.7.60/lang/hdl/vhdl/lexer.pm	2010-05-15 19:27:17.492163661 +0530
@@ -1,4 +1,4 @@
-package lang::hdl::vhdl::lexer;
+package HCT::lang::hdl::vhdl::lexer;
 
 use base 'HCT::Lang::LexerDriver';
 
diff -up hct-0.7.60/lang/hdl/vhdl/parser.pm.hct hct-0.7.60/lang/hdl/vhdl/parser.pm
--- hct-0.7.60/lang/hdl/vhdl/parser.pm.hct	2010-05-15 19:27:02.506162103 +0530
+++ hct-0.7.60/lang/hdl/vhdl/parser.pm	2010-05-15 19:27:36.632161539 +0530
@@ -12,7 +12,7 @@
 #
 ####################################################################
 
-package lang::hdl::vhdl::parser;
+package HCT::lang::hdl::vhdl::parser;
 use vars qw (@ISA);
 use strict;
 
diff -up hct-0.7.60/lang/hdl/vhdl.pm.hct hct-0.7.60/lang/hdl/vhdl.pm
--- hct-0.7.60/lang/hdl/vhdl.pm.hct	2010-05-15 19:21:04.081161427 +0530
+++ hct-0.7.60/lang/hdl/vhdl.pm	2010-05-15 19:24:09.765291668 +0530
@@ -1,4 +1,4 @@
-# vhdl.pm (lang::hdl::vhdl)
+# vhdl.pm (HCT::lang::hdl::vhdl)
 #
 # Copyright 2008, 2009
 # Slade Maurer
@@ -20,7 +20,7 @@
 
 =head1 NAME
 
-lang::hdl::vhdl - Class of VHDL language. 
+HCT::lang::hdl::vhdl - Class of VHDL language. 
 
 =head1 DESCRIPTION
 
@@ -40,7 +40,7 @@ with those expected. VHDL is a strongly 
 
 =cut
 
-package lang::hdl::vhdl;
+package HCT::lang::hdl::vhdl;
 
 # Use base object for creating a new language.
 use base 'HCT::Lang::LangDriver';
@@ -48,8 +48,8 @@ use base 'HCT::Lang::LangDriver';
 use strict;
 use warnings;
 
-require lang::hdl::vhdl::lexer;
-require lang::hdl::vhdl::parser;
+require HCT::lang::hdl::vhdl::lexer;
+require HCT::lang::hdl::vhdl::parser;
 
 our @FILE_ASSOCIATIONS = ('vhdl');
 
@@ -71,8 +71,8 @@ sub new
 	my $class = shift;
 	my $self = $class->SUPER::new (@_);
 
-	$self->parser (new lang::hdl::vhdl::parser);
-	$self->lexer (new lang::hdl::vhdl::lexer);
+	$self->parser (new HCT::lang::hdl::vhdl::parser);
+	$self->lexer (new HCT::lang::hdl::vhdl::lexer);
 
 	$self->output->metrics (\%OUTPUT_METRICS);
 	$self->output->levels  (\%OUTPUT_LEVELS);
diff -up hct-0.7.60/lang/init.pl.hct hct-0.7.60/lang/init.pl
--- hct-0.7.60/lang/init.pl.hct	2010-05-15 18:49:42.198184344 +0530
+++ hct-0.7.60/lang/init.pl	2010-05-15 18:50:01.868292676 +0530
@@ -2,7 +2,7 @@
 # WARNING: DO NOT EDIT THIS FILE, USE MAKEFILE INSTEAD.
 #          ANY CHANGE MADE HERE WILL BE LOST!
 
-HCT::Lang->load ('verilog','hdl/verilog.pm','lang::hdl::verilog');
-HCT::Lang->load ('cdl','hdl/cdl.pm','lang::hdl::cdl');
-HCT::Lang->load ('vhdl','hdl/vhdl.pm','lang::hdl::vhdl');
+HCT::Lang->load ('verilog','hdl/verilog.pm','HCT::lang::hdl::verilog');
+HCT::Lang->load ('cdl','hdl/cdl.pm','HCT::lang::hdl::cdl');
+HCT::Lang->load ('vhdl','hdl/vhdl.pm','HCT::lang::hdl::vhdl');
 1;
diff -up hct-0.7.60/src/perllib/HCT/Lang.pm.hct hct-0.7.60/src/perllib/HCT/Lang.pm
--- hct-0.7.60/src/perllib/HCT/Lang.pm.hct	2010-05-15 19:15:43.961162174 +0530
+++ hct-0.7.60/src/perllib/HCT/Lang.pm	2010-05-15 19:17:19.772190452 +0530
@@ -80,7 +80,7 @@ Contents path to the init-script file.
 
 =cut
 
-$INITSCRIPT = join '/' => ($ENV{HCTHOME}, 'lang', 'init.pl');
+$INITSCRIPT = join '/' => ($ENV{HCTHOME}, 'HCT', 'lang', 'init.pl');
 
 =head1 METHODS
 
@@ -181,7 +181,7 @@ sub load
 	my $class = shift;
 	my $name = shift;
 	my $unified_name = HCT::Lang->unify_name ($name);
-	my $file = join '/' => ($ENV{HCTHOME}, 'lang', shift);
+	my $file = join '/' => ($ENV{HCTHOME}, 'HCT', 'lang', shift);
 	my $package = shift;
 
 	# Checking the file...
diff -up hct-0.7.60/lang/hdl/cdl/lexer.pm.hct hct-0.7.60/lang/hdl/cdl/lexer.pm
--- hct-0.7.60/lang/hdl/cdl/lexer.pm.hct	2010-05-15 19:24:17.160287035 +0530
+++ hct-0.7.60/lang/hdl/cdl/lexer.pm	2010-05-15 19:24:44.980169323 +0530
@@ -1,4 +1,4 @@
 # lexer.pm (lang::hdl::cdl::lexer) - CDL Lexer.
 #
 # Copyright 2008, 2009
 # Slade Maurer
@@ -18,7 +18,7 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with HCT.  If not, see <http://www.gnu.org/licenses/>.
 
-package lang::hdl::cdl::lexer;
+package HCT::lang::hdl::cdl::lexer;
 
 use base 'HCT::Lang::LexerDriver';
 
@@ -1,4 +1,4 @@
-# lexer.pm (lang::hdl::cdl::lexer) - CDL Lexer.
+# lexer.pm (HCT::lang::hdl::cdl::lexer) - CDL Lexer.
 #
 # Copyright 2008, 2009